# Djatalist

[![PyPI - Version](https://img.shields.io/pypi/v/djatalist.svg)](https://pypi.org/project/djatalist)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/djatalist.svg)](https://pypi.org/project/djatalist)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```shell
pip install djatalist
```

Add to installed apps

```python
INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',

    'djatalist',
]
```


## License

`djatalist` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
